==> vala-0.1.0.tar.bz2: vala-0.1.0/vala/valawhilestatement.h <==
/* valawhilestatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALAWHILESTATEMENT_H__
#define __VALAWHILESTATEMENT_H__
typedef struct _ValaWhileStatementPrivate ValaWhileStatementPrivate;

#include <glib.h>
#include <glib-object.h>
#include <vala/valastatement.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
#define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
#define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
#define VALA_IS_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_WHILE_STATEMENT))
#define VALA_IS_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_WHILE_STATEMENT))
#define VALA_WHILE_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))


/**
 * Represents a while iteration statement in the source code.
 */
struct _ValaWhileStatement {
	ValaStatement parent;
	ValaWhileStatementPrivate * priv;
};
struct _ValaWhileStatementClass {
	ValaStatementClass parent;
};

ValaWhileStatement* vala_while_statement_new (ValaExpression* cond, ValaStatement* _body, ValaSourceReference* source);
ValaExpression* vala_while_statement_get_condition (ValaWhileStatement* self);
void vala_while_statement_set_condition (ValaWhileStatement* self, ValaExpression* value);
ValaStatement* vala_while_statement_get_body (ValaWhileStatement* self);
void vala_while_statement_set_body (ValaWhileStatement* self, ValaStatement* value);
GType vala_while_statement_get_type ();

G_END_DECLS

#endif

==> vala-0.1.4.tar.bz2: vala-0.1.4/vala/valawhilestatement.h <==
/* valawhilestatement.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAWHILESTATEMENT_H__
#define __VALA_VALAWHILESTATEMENT_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valacodenode.h>
#include <vala/valastatement.h>

G_BEGIN_DECLS


#define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
#define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
#define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
#define VALA_IS_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_WHILE_STATEMENT))
#define VALA_IS_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_WHILE_STATEMENT))
#define VALA_WHILE_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))

typedef struct _ValaWhileStatementPrivate ValaWhileStatementPrivate;

/**
 * Represents a while iteration statement in the source code.
 */
struct _ValaWhileStatement {
	ValaCodeNode parent;
	ValaWhileStatementPrivate * priv;
};
struct _ValaWhileStatementClass {
	ValaCodeNodeClass parent;
};

ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
ValaExpression* vala_while_statement_get_condition (ValaWhileStatement* self);
void vala_while_statement_set_condition (ValaWhileStatement* self, ValaExpression* value);
ValaBlock* vala_while_statement_get_body (ValaWhileStatement* self);
void vala_while_statement_set_body (ValaWhileStatement* self, ValaBlock* value);
GType vala_while_statement_get_type (void);

G_END_DECLS

#endif
